pub struct ParameterReflection {
pub name: &'static str,
pub description: &'static str,
pub is_optional: bool,
}Expand description
A structure that holds the information of a single parameter in a filter. This includes its name, description and whether it is optional or required.
This is the return type in some FilterReflection functions.
Fields
name: &'static strdescription: &'static stris_optional: boolAuto Trait Implementations
impl Freeze for ParameterReflection
impl RefUnwindSafe for ParameterReflection
impl Send for ParameterReflection
impl Sync for ParameterReflection
impl Unpin for ParameterReflection
impl UnsafeUnpin for ParameterReflection
impl UnwindSafe for ParameterReflection