FilterParametersReflection

Trait FilterParametersReflection 

pub trait FilterParametersReflection {
    // Required methods
    fn positional_parameters() -> &'static [ParameterReflection];
    fn keyword_parameters() -> &'static [ParameterReflection];
}
A trait that holds the information of the parameters of a filter.

All structs that implement FilterParameters must implement this. This is actually automatically implemented with #[derive(FilterParameters)].

This trait allows FilterReflection macro to extract the parameters information from a given FilterParameters structure.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors